"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.putAt = void 0;

var _typeof2 = _interopRequireDefault(require("@babel/runtime/helpers/typeof"));

/**
 * Finds a property in an object. Property can be nested by using ".".
 * @param {string | string[]} path The path of the property.
 * @param {any} obj The object to get the property in.
 */
var at = function at(path, obj) {
  if (path === "" || Array.isArray(path) && path.length === 0) {
    return obj;
  }

  path = Array.isArray(path) ? path : path.split(".");

  for (var i = 0; i < path.length; i++) {
    obj = obj && obj[path[i]];
  }

  return obj;
};
/**
 * Puts an object into an object. MUTATES THE OBJECT.
 * @param {string | string[]} path The path of the property.
 * @param {any} obj The object to put the property in.
 */


var putAt = function putAt(path, obj, value) {
  if (path === "" || Array.isArray(path) && path.length === 0) {
    return value;
  }

  var root = obj;
  path = Array.isArray(path) ? path : path.split(".");

  for (var i = 0; i < path.length - 1; i++) {
    var newObj = obj[path[i]];

    if (newObj === null || (0, _typeof2.default)(newObj) !== "object") {
      newObj = {};
      obj[path[i]] = newObj;
    }

    obj = newObj;
  }

  obj[path[path.length - 1]] = value;
  return root;
};

exports.putAt = putAt;
var _default = at;
exports.default = _default;